Enum ChangeCause
#[non_exhaustive]#[repr(u32)]pub enum ChangeCause {
InputMethod = 0,
Other = 1,
}Available on crate feature
wayland and Linux only.Expand description
text change reason
Reason for the change of surrounding text or cursor posision.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputMethod = 0
input method caused the change
Other = 1
something else than the input method caused the change