Struct ContentHint
pub struct ContentHint(/* private fields */);wayland and Linux only.Expand description
content hint
Content hint is a bitmask to allow to modify the behavior of the text input.
Implementations
impl ContentHint
impl ContentHint
pub const None: ContentHint
pub const None: ContentHint
no special behavior
pub const Completion: ContentHint
pub const Completion: ContentHint
suggest word completions
pub const Spellcheck: ContentHint
pub const Spellcheck: ContentHint
suggest word corrections
pub const AutoCapitalization: ContentHint
pub const AutoCapitalization: ContentHint
switch to uppercase letters at the start of a sentence
pub const Lowercase: ContentHint
pub const Lowercase: ContentHint
prefer lowercase letters
pub const Uppercase: ContentHint
pub const Uppercase: ContentHint
prefer uppercase letters
pub const Titlecase: ContentHint
pub const Titlecase: ContentHint
prefer casing for titles and headings (can be language dependent)
pub const HiddenText: ContentHint
pub const HiddenText: ContentHint
characters should be hidden
pub const SensitiveData: ContentHint
pub const SensitiveData: ContentHint
typed text should not be stored
pub const Latin: ContentHint
pub const Latin: ContentHint
just Latin characters should be entered
pub const Multiline: ContentHint
pub const Multiline: ContentHint
the text input is multiline
impl ContentHint
impl ContentHint
pub const fn empty() -> ContentHint
pub const fn empty() -> ContentHint
Get a flags value with all bits unset.
pub const fn all() -> ContentHint
pub const fn all() -> ContentHint
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<ContentHint>
pub const fn from_bits(bits: u32) -> Option<ContentHint>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> ContentHint
pub const fn from_bits_truncate(bits: u32) -> ContentHint
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> ContentHint
pub const fn from_bits_retain(bits: u32) -> ContentHint
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ContentHint>
pub fn from_name(name: &str) -> Option<ContentHint>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: ContentHint) -> bool
pub const fn intersects(&self, other: ContentHint) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ContentHint) -> bool
pub const fn contains(&self, other: ContentHint) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ContentHint)
pub fn insert(&mut self, other: ContentHint)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ContentHint)
pub fn remove(&mut self, other: ContentHint)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ContentHint)
pub fn toggle(&mut self, other: ContentHint)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ContentHint, value: bool)
pub fn set(&mut self, other: ContentHint, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ContentHint) -> ContentHint
pub const fn intersection(self, other: ContentHint) -> ContentHint
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ContentHint) -> ContentHint
pub const fn union(self, other: ContentHint) -> ContentHint
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ContentHint) -> ContentHint
pub const fn difference(self, other: ContentHint) -> ContentHint
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: ContentHint) -> ContentHint
pub const fn symmetric_difference(self, other: ContentHint) -> ContentHint
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ContentHint
pub const fn complement(self) -> ContentHint
The bitwise negation (!) of the bits in self, truncating the result.
impl ContentHint
impl ContentHint
pub const fn iter(&self) -> Iter<ContentHint>
pub const fn iter(&self) -> Iter<ContentHint>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ContentHint>
pub const fn iter_names(&self) -> IterNames<ContentHint>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.